@@ -13,8 +13,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, a copy can be downloaded from 
+ * http://www.gnu.org/licenses/gpl.html, or obtained by writing to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ * Boston, MA 02110-1301, USA.
  */
 #include "directvnc.h"
 #include <math.h>
@@ -30,7 +32,7 @@ IDirectFBInputDevice    *mouse;
 IDirectFBEventBuffer    *input_buffer;
 DFBResult err;
 DFBSurfaceDescription dsc;
-DFBCardCapabilities caps;
+DFBGraphicsDeviceDescription caps;
 DFBDisplayLayerConfig layer_config;
 DFBRegion rect;
 DFBRectangle scratch_rect;
@@ -41,7 +43,9 @@ void
 dfb_init(int argc, char *argv[])
 {
      DFBCHECK(DirectFBInit( &argc, &argv ));
-     DFBCHECK(DirectFBSetOption ("quiet", ""));
+
+     /* quiet option is no longer supported in DFB 1.2 */
+     /* DFBCHECK(DirectFBSetOption ("quiet", "")); */
 
      /* create the super interface */
      DFBCHECK(DirectFBCreate( &dfb ));
