@@ -13,8 +13,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, a copy can be downloaded from 
+ * http://www.gnu.org/licenses/gpl.html, or obtained by writing to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -248,6 +250,8 @@ rfb_set_format_and_encodings()
    if (!write_exact(sock, (char*)&pf, sz_rfbSetPixelFormatMsg)) return 0;
 
    em.type = rfbSetEncodings;
+   em.nEncodings = 0;
+
    /* figure out the encodings string given on the command line */
    next = strtok(opt.encodings, " ");
    while (next && em.nEncodings < MAX_ENCODINGS)
